@@ -8,4 +8,7 @@ pub mod prelude {
     pub use crate::fieldofview::*;
     pub use bracket_algorithm_traits::prelude::*;
     pub use bracket_geometry::prelude::*;
-}
\ No newline at end of file
+
+    /// Since we use `SmallVec`, it's only polite to export it so you don't have to have multiple copies.
+    pub use smallvec::{SmallVec, smallvec};
+}
